@@ -6,10 +6,12 @@ use crate::response::*;
 use crate::selector::Selector;
 use crate::util::{validate_duration, RuleType, TargetState};
 use std::collections::HashMap;
+use std::fmt;
 use url::Url;
 
 /// A helper enum that is passed to the [Client::new] function in
 /// order to avoid errors on unsupported connection schemes.
+#[derive(Debug)]
 pub enum Scheme {
     Http,
     Https,
@@ -24,8 +26,18 @@ impl Scheme {
     }
 }
 
+impl fmt::Display for Scheme {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        match self {
+            Self::Http => write!(f, "http"),
+            Self::Https => write!(f, "https"),
+        }
+    }
+}
+
 /// A client used to execute queries. It uses a [reqwest::Client] internally
 /// that manages connections for us.
+#[derive(Clone)]
 pub struct Client {
     pub(crate) client: reqwest::Client,
     pub(crate) base_url: String,
